@@ -130,6 +130,7 @@ class QCE_EXPORT QEditor : public QAbstractScrollArea
 			CursorWordLeft,
 			CursorWordRight,
 			CursorStartOfLine,
+            CursorStartOfLineText,
 			CursorEndOfLine,
 			CursorStartOfDocument,
 			CursorEndOfDocument,
@@ -146,6 +147,7 @@ class QCE_EXPORT QEditor : public QAbstractScrollArea
 			SelectCursorWordLeft,
 			SelectCursorWordRight,
 			SelectCursorStartOfLine,
+            SelectCursorStartOfLineText,
 			SelectCursorEndOfLine,
 			SelectCursorStartOfDocument,
 			SelectCursorEndOfDocument,
@@ -311,11 +313,7 @@ class QCE_EXPORT QEditor : public QAbstractScrollArea
         }
         inline qreal verticalOffset() const
         {
-#if defined Q_OS_MAC
-            return verticalScrollBar()->value() * m_doc->getLineSpacing();  // does this work always ?
-#else
-            return verticalScrollBar()->isVisible() ? 1. * verticalScrollBar()->value() * m_doc->getLineSpacing() : 0;
-#endif
+            return 1. * verticalScrollBar()->value() * m_doc->getLineSpacing();
         }
 		
 		inline QPoint mapToContents(const QPoint &point) const
