@@ -13,6 +13,7 @@ TxsTabWidget::TxsTabWidget(QWidget *parent) :
 	ChangeAwareTabBar *tb = new ChangeAwareTabBar();
 	tb->setContextMenuPolicy(Qt::CustomContextMenu);
 	tb->setUsesScrollButtons(true);
+    //tb->setAutoHide(true);
 	connect(tb, SIGNAL(customContextMenuRequested(QPoint)), this, SIGNAL(tabBarContextMenuRequested(QPoint)));
     connect(tb, SIGNAL(currentTabAboutToChange(int,int)), this, SLOT(currentTabAboutToChange(int,int)));
 	connect(tb, SIGNAL(tabLeftClicked()), this, SIGNAL(activationRequested()));
@@ -74,9 +75,7 @@ void TxsTabWidget::setCurrentEditor(LatexEditorView *edView)
 		// catch calls in which editor is not a member tab.
 		// TODO: such calls are deprecated as bad practice. We should avoid them in the long run. For the moment the fallback to do nothing is ok.
 		qDebug() << "Warning (deprecated call): TxsTabWidget::setCurrentEditor: editor not member of TxsTabWidget" << edView;
-#ifndef QT_NO_DEBUG
-		UtilsUi::txsWarning("Warning (deprecated call): TxsTabWidget::setCurrentEditor: editor not member of TxsTabWidget");
-#endif
+
 		return;
 	}
 	setCurrentWidget(edView);
@@ -105,6 +104,10 @@ void TxsTabWidget::setActive(bool active) {
 	} else {
 		setStyleSheet(baseStyle + " QTabBar {color: darkgrey;}");
 	}
+    if(active){
+        if(currentEditor())
+            currentEditor()->setFocus();
+    }
 }
 
 bool TxsTabWidget::isEmpty() const {
